.. natsort documentation master file, created by
   sphinx-quickstart on Thu Jul 17 21:01:29 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

natsort: Simple yet flexible natural sorting in Python.
=======================================================

    - Source Code: https://github.com/SethMMorton/natsort
    - Downloads: https://pypi.org/project/natsort/
    - Documentation: https://natsort.readthedocs.io/

Please see the `GitHub main page <https://github.com/SethMMorton/natsort#natsort>`_
for everything else, including

    - Quick description
    - Basic examples
    - FAQ
    - Requirements and optional dependencies
    - Installation instructions
    - Testing instructions
    - Deprecation schedule

.. toctree::
   :maxdepth: 2
   :numbered:

   howitworks.rst
   examples.rst
   api.rst
   locale_issues.rst
   shell.rst
   changelog.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
